Tool for reading/writing PCAPNG network packet capture files
============================================================

Alan Thompson, Brocade
athomps@brocade.com

Please see the IETF document `PCAP Next Generation (pcapng) Capture File Format <https://pcapng.github.io/pcapng/>`_

Please also see the project `home page on GitLab <https://gitlab.com/netdev-americas/pcapng/>`_

